<?php
/**
 * yuno Theme Customizer
 *
 * @package yuno
 */

/*-----------------------------------------------------------------------------------------------------------------------*/

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function yuno_customize_register( $wp_customize ) {
	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';

	if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial(
			'blogname',
			array(
				'selector'        => '.site-title a',
				'render_callback' => 'yuno_customize_partial_blogname',
			)
		);
		$wp_customize->selective_refresh->add_partial(
			'blogdescription',
			array(
				'selector'        => '.site-description',
				'render_callback' => 'yuno_customize_partial_blogdescription',
			)
		);
	}
}
add_action( 'customize_register', 'yuno_customize_register' );

/*-----------------------------------------------------------------------------------------------------------------------*/

/**
 * Render the site title for the selective refresh partial.
 *
 * @return void
 */
function yuno_customize_partial_blogname() {
	bloginfo( 'name' );
}

/*-----------------------------------------------------------------------------------------------------------------------*/

/**
 * Render the site tagline for the selective refresh partial.
 *
 * @return void
 */
function yuno_customize_partial_blogdescription() {
	bloginfo( 'description' );
}

/*-----------------------------------------------------------------------------------------------------------------------*/

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function yuno_customize_preview_js() {
	wp_enqueue_script( 'yuno-customizer', get_template_directory_uri() . '/assets/js/customizer.js', array( 'customize-preview' ), yuno_THEME_VERSION, true );
}
add_action( 'customize_preview_init', 'yuno_customize_preview_js' );

/*-----------------------------------------------------------------------------------------------------------------------*/
/**
 * Enqueue required scripts/styles for customizer panel
 *
 * @since 1.0.0
 */
function yuno_customize_backend_scripts() {

    wp_enqueue_style( 'font-awesome', get_template_directory_uri() . '/assets/css/font-awesome/css/all.css', array(), '5.3.1' );    
    wp_enqueue_style( 'yuno_admin_customizer_style', get_template_directory_uri() . '/assets/css/yuno-customizer-style.css' );

	wp_enqueue_script( "jquery-effects-core" );
    wp_enqueue_script( 'yuno_admin_customizer', get_template_directory_uri() . '/assets/js/yuno-customizer-controls.js', array( 'jquery', 'customize-controls' ), yuno_THEME_VERSION, true );
}
add_action( 'customize_controls_enqueue_scripts', 'yuno_customize_backend_scripts', 10 );

/*-----------------------------------------------------------------------------------------------------------------------*/

/**
 * Load required files for customizer section
 *
 * @since 1.0.0
 */
get_template_part( 'inc/customizer/custom', 'classes' );      // Custom Classes
get_template_part( 'inc/customizer/sanitize', 'callback' ); // Customizer Sanitize
get_template_part( 'inc/customizer/general', 'panel' );       // General Settings
get_template_part( 'inc/customizer/header', 'layout' );       // Header Layout
get_template_part( 'inc/customizer/archive', 'layout' );       // archive Pages layout
get_template_part( 'inc/customizer/single', 'layout' );       // single Posts layout
get_template_part( 'inc/customizer/footer', 'layout' );       // footer layout