<?php
/**
 * Yuno Footer Settings panel at Theme Customizer
 *
 * @package Yuno
 * @since 1.0.0
 */

add_action( 'customize_register', 'yuno_footer_settings_register' );

function yuno_footer_settings_register( $wp_customize ) {

	/**
     * Add Additional Settings Panel
     *
     * @since 1.0.0
     */
    $wp_customize->add_panel(
	    'yuno_footer_settings_panel',
	    array(
	        'priority'       => 30,
	        'capability'     => 'edit_theme_options',
	        'theme_supports' => '',
	        'title'          => esc_html__( 'Footer Settings', 'yuno' ),
	    )
    );

/*-----------------------------------------------------------------------------------------------------------------------*/
    
    /**
	 * Bottom Section
	 *
	 * @since 1.0.0
	 */
	$wp_customize->add_section(
        'yuno_footer_bottom_section',
        array(
            'title'	   => esc_html__( 'Bottom Section', 'yuno' ),
            'panel'    => 'yuno_footer_settings_panel',
            'priority' => 10,
        )
    );

/*-----------------------------------------------------------------------------------------------------------------------*/

    /**
     * Text field for copyright
     *
     * @since 1.0.0
     */
    $wp_customize->add_setting(
        'yuno_copyright_text',
        array(
            'default'           => esc_html__( 'Copyright © 2021 | All Rights Reserved.', 'yuno' ),
            'sanitize_callback' => 'yuno_sanitize_html'
            )
    );
    $wp_customize->add_control(
        'yuno_copyright_text',
        array(
            'type'        => 'textarea',
            'label'       => esc_html__( 'Copyright Text', 'yuno' ),
            'description' => esc_html__( 'You can use html tags also.', 'yuno' ),
            'section'     => 'yuno_footer_bottom_section',
            'priority'    => 5
        )
    );

/*-----------------------------------------------------------------------------------------------------------------------*/

    /**
     * Text color for copyright
     *
     * @since 1.0.0
     */
    $wp_customize->add_setting(
        'yuno_copyright_text_color',
        array(
            'default'           => '#191919',
            'transport'         => 'refresh',
            'sanitize_callback' => 'sanitize_text_field'
        )
    );
    $wp_customize->add_control( 
        new WP_Customize_Color_Control( 
            $wp_customize, 'yuno_copyright_text_color', 
            array(
                'label'      => esc_html__( 'Select copyright text color', 'yuno' ),
                'section'    => 'yuno_footer_bottom_section',
                'settings'   => 'yuno_copyright_text_color',
            ) 
        ) 
    );

/*-----------------------------------------------------------------------------------------------------------------------*/

    /**
     * Text color for copyright
     *
     * @since 1.0.0
     */
    $wp_customize->add_setting(
        'yuno_fwidget_text_color',
        array(
            'default'   => '#162238',
            'transport' => 'refresh',
            'sanitize_callback' => 'sanitize_text_field'
        )
    );
    $wp_customize->add_control( 
        new WP_Customize_Color_Control( 
            $wp_customize, 'yuno_fwidget_text_color', 
            array(
                'label'      => esc_html__( 'Footer Widget Section color', 'yuno' ),
                'section'    => 'yuno_footer_bottom_section',
                'settings'   => 'yuno_fwidget_text_color',
            ) 
        ) 
    );

/*-----------------------------------------------------------------------------------------------------------------------*/

}