<?php
/**
 * Yuno Header Settings panel at Theme Customizer
 *
 * @package Yuno
 * @since 1.0.0
 */

add_action( 'customize_register', 'yuno_header_settings_register' );

function yuno_header_settings_register( $wp_customize ) {

	/**
     * Add General Settings Panel
     *
     * @since 1.0.0
     */
    $wp_customize->add_panel(
	    'yuno_header_settings_panel',
	    array(
	        'priority'       => 10,
	        'capability'     => 'edit_theme_options',
	        'theme_supports' => '',
	        'title'          => esc_html__( 'Header Settings', 'yuno' ),
	    )
    );
    
    /*-----------------------------------------------------------------------------------------------------------------------*/

    /**
     * Header Option Section
     */
    $wp_customize->add_section(
        'yuno_header_option_section',
        array(
            'title'    => esc_html__( 'Header Options', 'yuno' ),
            'priority' => 10,
            'panel'    => 'yuno_header_settings_panel',
        )
    );

    /**
     * Switch option for Home Icon
     *
     * @since 1.0.0
     */
    $wp_customize->add_setting(
        'yuno_menu_sticky_option',
        array(
            'default'           => 'show',
            'sanitize_callback' => 'yuno_sanitize_switch_option',
        )
    );
    $wp_customize->add_control( new yuno_Customize_Switch_Control(
        $wp_customize,
        'yuno_menu_sticky_option',
        array(
            'type'        => 'yuno-switch',
            'label'       => esc_html__( 'Sticky Menu', 'yuno' ),
            'description' => esc_html__( 'Enable/Disable option for sticky menu.', 'yuno' ),
            'section'     => 'yuno_header_option_section',
            'choices'     => array(
                'show' => esc_html__( 'Enable', 'yuno' ),
                'hide' => esc_html__( 'Disable', 'yuno' ),
            ),
            'priority'    => 5,
        )
    )
    );

    /**
     * Switch option Header Background
     *
     * @since 1.0.0
     */
    $wp_customize->add_setting(
        'yuno_header_bg_option',
        array(
            'default'           => 'hide',
            'sanitize_callback' => 'yuno_sanitize_switch_option',
        )
    );
    $wp_customize->add_control( new yuno_Customize_Switch_Control(
        $wp_customize,
        'yuno_header_bg_option',
        array(
            'type'        => 'yuno-switch',
            'label'       => esc_html__( 'Header Transparency', 'yuno' ),
            'description' => esc_html__( 'Enable/Disable option for header transparency.', 'yuno' ),
            'section'     => 'yuno_header_option_section',
            'choices'     => array(
                'show' => esc_html__( 'Enable', 'yuno' ),
                'hide' => esc_html__( 'Disable', 'yuno' ),
            ),
            'priority'    => 5,
        )
    )
    );

    /**
     * Switch option Header top bar
     *
     * @since 1.0.0
     */
    $wp_customize->add_setting(
        'yuno_top_bar_switch',
        array(
            'default'           => 'show',
            'sanitize_callback' => 'yuno_sanitize_switch_option',
        )
    );
    $wp_customize->add_control( new yuno_Customize_Switch_Control(
        $wp_customize,
        'yuno_top_bar_switch',
        array(
            'type'        => 'yuno-switch',
            'label'       => esc_html__( 'Header Top bar', 'yuno' ),
            'description' => esc_html__( 'Enable/Disable option for header top bar.', 'yuno' ),
            'section'     => 'yuno_header_option_section',
            'choices'     => array(
                'show' => esc_html__( 'Enable', 'yuno' ),
                'hide' => esc_html__( 'Disable', 'yuno' ),
            ),
            'priority'    => 5,
        )
    )
    );

    /**
     * Switch option Header Social icons
     *
     * @since 1.0.0
     */
    $wp_customize->add_setting(
        'yuno_social_icons_switch',
        array(
            'default'           => 'show',
            'sanitize_callback' => 'yuno_sanitize_switch_option',
        )
    );
    $wp_customize->add_control( new yuno_Customize_Switch_Control(
        $wp_customize,
        'yuno_social_icons_switch',
        array(
            'type'        => 'yuno-switch',
            'label'       => esc_html__( 'Social Icons', 'yuno' ),
            'description' => esc_html__( 'Enable/Disable option for header social icons.', 'yuno' ),
            'section'     => 'yuno_header_option_section',
            'choices'     => array(
                'show' => esc_html__( 'Enable', 'yuno' ),
                'hide' => esc_html__( 'Disable', 'yuno' ),
            ),
            'priority'    => 5,
        )
    )
    );

    /*-----------------------------------------------------------------------------------------------------------------------*/

    /**
     * Header Option Section
     */
    $wp_customize->add_section(
        'yuno_beadcrumb_option_section',
        array(
            'title'    => esc_html__( 'Breadcrumb Options', 'yuno' ),
            'priority' => 10,
            'panel'    => 'yuno_header_settings_panel',
        )
    );

    /**
     * Switch option for Search Icon
     *
     * @since 1.0.0
     */
    $wp_customize->add_setting(
        'yuno_bead_div_option',
        array(
            'default'           => 'show',
            'sanitize_callback' => 'yuno_sanitize_switch_option',
        )
    );
    $wp_customize->add_control( new yuno_Customize_Switch_Control(
        $wp_customize,
        'yuno_bead_div_option',
            array(
                'type'        => 'yuno-switch',
                'label'       => esc_html__( 'Breadcrumb Section', 'yuno' ),
                'description' => esc_html__( 'Show/Hide breadcrumb section from top.', 'yuno'),
                'section'     => 'yuno_beadcrumb_option_section',
                'choices'     => array(
                    'show' => esc_html__( 'Show', 'yuno' ),
                    'hide' => esc_html__( 'Hide', 'yuno' ),
                ),
                'priority'    => 10,
            )
        )
    );

    /*-----------------------------------------------------------------------------------------------------------------------*/

    /**
     * Header Option Section
     */
    $wp_customize->add_section(
        'yuno_header_social_icon_options',
        array(
            'title'    => esc_html__( 'Social Icons', 'yuno' ),
            'priority' => 10,
            'panel'    => 'yuno_header_settings_panel',
        )
    );

    /**
     * Repeater field for social media icons
     *
     * @since 1.0.0
     */
    $wp_customize->add_setting( 
        'yuno_social_media_icons', 
        array(
            'sanitize_callback' => 'yuno_sanitize_repeater',
            'default' => json_encode( array(
                array(
                    'social_icon_class' => 'fab fa-facebook-f',
                    'social_icon_url'   => '',
                    )
            ))
        )
    );
    $wp_customize->add_control( new yuno_Repeater_Controler(
        $wp_customize, 
            'yuno_social_media_icons', 
            array(
                'label'    => esc_html__( 'Social Media Icons', 'yuno' ),
                'section'  => 'yuno_header_social_icon_options',
                'settings' => 'yuno_social_media_icons',
                'priority' => 5,
                'rdcode_box_label'       => esc_html__( 'Social Media Icon','yuno' ),
                'rdcode_box_add_control' => esc_html__( 'Add Icon','yuno' )
            ),
            array(
                'social_icon_class' => array(
                    'type'        => 'social_icon',
                    'label'       => esc_html__( 'Social Media Logo', 'yuno' ),
                    'description' => esc_html__( 'Choose social media icon.', 'yuno' )
                ),
                'social_icon_url' => array(
                    'type'        => 'url',
                    'label'       => esc_html__( 'Social Icon Url', 'yuno' ),
                    'description' => esc_html__( 'Enter social media url.', 'yuno' )
                )
            )
        ) 
    );

    /*-----------------------------------------------------------------------------------------------------------------------*/

    /**
     * Header contact Option Section
     */
    $wp_customize->add_section(
        'yuno_header_contact_options',
        array(
            'title'    => esc_html__( 'Contact Details', 'yuno' ),
            'priority' => 10,
            'panel'    => 'yuno_header_settings_panel',
        )
    );

    $wp_customize->add_setting(
        'yuno_phone_number',
        array(
            'default'           => '+123-456-7890',
            'transport'         => 'postMessage',
            'sanitize_callback' => 'sanitize_text_field'
            )
    );
    $wp_customize->add_control(
        'yuno_phone_number',
        array(
            'type'     => 'text',
            'label'    => esc_html__( 'Contact Number', 'yuno' ),
            'section'  => 'yuno_header_contact_options',
            'priority' => 5
        )
    );

    $wp_customize->add_setting(
        'yuno_email_address',
        array(
            'default'           => 'info@example.com',
            'transport'         => 'postMessage',
            'sanitize_callback' => 'sanitize_text_field'
            )
    );
    $wp_customize->add_control(
        'yuno_email_address',
        array(
            'type'     => 'text',
            'label'    => esc_html__( 'Email Address', 'yuno' ),
            'section'  => 'yuno_header_contact_options',
            'priority' => 5
        )
    );

}